# eric7.UI.FindFileFilterPropertiesDialog

Module implementing a dialog to enter the file filter properties.

### Global Attributes

None

### Classes

FindFileFilterPropertiesDialog | Class implementing a dialog to enter the file filter properties.

### Functions

None

## FindFileFilterPropertiesDialog

Class implementing a dialog to enter the file filter properties.

### Derived from

QDialog, Ui_FindFileFilterPropertiesDialog

### Class Attributes

None

### Class Methods

None

### Methods

FindFileFilterPropertiesDialog | Constructor
__updateOKAndError | Private slot to set the enabled state of the OK button.
getProperties | Public method to retrieve the entered filter properties.

### Static Methods

None

#### FindFileFilterPropertiesDialog (Constructor)

FindFileFilterPropertiesDialog(currentFilters, properties=None, parent=None)

Constructor

currentFilters (list of str)
  list of existing filters to check against
properties (tuple of (str, str) (optional))
  tuple containing the filter name and pattern to be edited (defaults to None)
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### FindFileFilterPropertiesDialog.__updateOKAndError

__updateOKAndError()

Private slot to set the enabled state of the OK button.

#### FindFileFilterPropertiesDialog.getProperties

getProperties()

Public method to retrieve the entered filter properties.

Return:
  tuple cotaining the filter name and pattern

Return Type:
  tuple of (str, str)

Up